#!/usr/bin/env node

const fs = require('fs');
const path = require('path');

// Get arguments passed to the command
const args = process.argv.slice(2);

// Helper function to show usage instructions
function showHelp() {
    console.log(`Usage:
            my-command  [argunts]
            Operations:
            generate-component       Generate a React component
            list-files              List all files in a directory
            create-file         Create a file with content
            delete-file                  Delete a file
            Examples:
            my-command generate-component MyComponent
            my-command list-files ./src
            my-command create-file ./src/test.txt "Hello, World!"
            my-command delete-file ./src/test.txt
            `);
}
// Handle no arguments or help flag
if (args.includes('--help') || args.length === 0) {
    showHelp();
    process.exit(0);
}
// Parse the operation
const operation = args[0]
// Switch case to handle different operations
switch (operation) {
    case 'generate-component': {
        const componentName = args[1];
        if (!componentName) {
            console.error("Error: Please provide a component name!");
            process.exit(1);
        }
        const filePath = args[1];
        const content = args.slice(2).join(' ');

        if (!filePath) {
            console.error("Error: Please provide a file path!");
            process.exit(1);
        }

        fs.mkdirSync(path.dirname(filePath), { recursive: true });
        fs.writeFileSync(filePath, content);
        console.log(`File '${filePath}' created successfully!`);
        break;
    }

    case 'delete-file': {
        const filePath = args[1];
        if (!filePath) {
            console.error("Error: Please provide a file path to delete!");
            process.exit(1);
        }

        if (!fs.existsSync(filePath)) {
            console.error("Error: File does not exist!");
            process.exit(1);
        }

        fs.unlinkSync(filePath);
        console.log(`File '${filePath}' deleted successfully!`);
        break;
    }

    default:
        console.error(`Error: Unknown operation '${operation}'`);
        showHelp();
        process.exit(1);
}